!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = meter  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 3.0E-002  &
   spacing_for_grid = 1.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = UGCV  &
   comments = "Unmanned Ground Combat Vehicle", "",  &
              "Walt Daniel, 12 November 2008", "",  &
              "This is a simplified model of a military rover that would be",  &
              "used in combat areas.  The wheels are machined aluminum or steel",  &
              "so a pneumatic tire model isn't appropriate; solid contacts are",  &
              "used between each of the four wheels and the extrusion geometry on",  &
              "the ground part.", "",  &
              "The wheels are driven by constant rate angular motions--torques",  &
              "with limits would be a better model of the electric motors.  The",  &
              "motions all reference the design variable wheel_rate.", "",  &
              "The suspension is a simple plunger (preloaded spring-damper) on each",  &
              "wheel.  There are design variables for stiffness, damping, and preload.",  &
              "",  &
              "The front wheels are steered with motions that both reference the",  &
              "state variable cmd_heading which is the commanded steering angle.  This",  &
              "is open-loop perfect steering (i.e., no closed-loop path following).",  &
              "The state variable is just the summation of two step functions to ",  &
              "sweep the steering right and left."
!
model attributes  &
   model_name = UGCV  &
   size_of_icons = 3.0E-002
!
view erase
!
!-------------------------------- Data storage --------------------------------!
!
!
data_element create variable  &
   variable_name = .UGCV.cmd_heading  &
   adams_id = 13  &
   initial_condition = 0.0  &
   function = ""
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .UGCV.steel  &
   adams_id = 2  &
   youngs_modulus = 2.07E+011  &
   poissons_ratio = 0.29  &
   density = 7801.0
!
material create  &
   material_name = .UGCV.aluminum  &
   adams_id = 1  &
   youngs_modulus = 7.1705E+010  &
   poissons_ratio = 0.33  &
   density = 2740.0
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.ground.MARKER_63  &
   adams_id = 63  &
   location = -0.8, 0.0, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.ground  &
   material_type = .UGCV.steel
!
! ****** Graphics for current part ******
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground.MARKER_63
!
geometry create shape extrusion  &
   extrusion_name = .UGCV.ground.EXTRUSION_34  &
   reference_marker = .UGCV.ground.MARKER_63  &
   analytical = no  &
   points_for_profile = 0.0, 0.0, -2.5  &
      , 2.6, 0.0, -2.5  &
      , 3.3, 0.4, -2.5  &
      , 4.0, 0.1, -2.5  &
      , 9.0426968553, -9.3526160683E-002, -2.5  &
      , 0.0, -0.1, -2.5  &
      , 0.0, 0.0, -2.5  &
   length_along_z_axis = 8.0
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part attributes  &
   part_name = .UGCV.ground  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- wheel_LF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.wheel_LF  &
   adams_id = 16  &
   location = 1.9, 0.0, 0.65  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.wheel_LF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.wheel_LF.MARKER_65  &
   adams_id = 65  &
   location = -1.4, 0.1, -0.95  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.wheel_LF.cm  &
   adams_id = 68  &
   location = -1.4, 0.1, -0.9  &
   orientation = 270.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .UGCV.wheel_LF.MARKER_16  &
   adams_id = 16  &
   location = -1.4, 0.1, -0.9  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_16  &
   size_of_icons = 3.0E-002
!
part create rigid_body mass_properties  &
   part_name = .UGCV.wheel_LF  &
   density = 400.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.wheel_LF.CYLINDER_47  &
   adams_id = 47  &
   center_marker = .UGCV.wheel_LF.MARKER_65  &
   angle_extent = 360.0  &
   length = 0.1  &
   radius = 0.12  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.wheel_LF  &
   color = DARK_GRAY  &
   name_visibility = off
!
!---------------------------------- wheel_RR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.wheel_RR  &
   adams_id = 17  &
   location = 0.7, 0.0, 0.35  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.wheel_RR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.wheel_RR.MARKER_69  &
   adams_id = 69  &
   location = -1.2, 0.1, -0.15  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.wheel_RR.cm  &
   adams_id = 72  &
   location = -1.2, 0.1, -0.1  &
   orientation = 270.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .UGCV.wheel_RR.MARKER_28  &
   adams_id = 28  &
   location = -1.2, 0.1, -0.1  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_28  &
   size_of_icons = 3.0E-002
!
part create rigid_body mass_properties  &
   part_name = .UGCV.wheel_RR  &
   density = 400.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.wheel_RR.CYLINDER_48  &
   adams_id = 48  &
   center_marker = .UGCV.wheel_RR.MARKER_69  &
   angle_extent = 360.0  &
   length = 0.1  &
   radius = 0.12  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.wheel_RR  &
   color = DARK_GRAY  &
   name_visibility = off
!
!---------------------------------- strut_RR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.strut_RR  &
   adams_id = 6  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.strut_RR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.strut_RR.MARKER_5  &
   adams_id = 5  &
   location = -0.5, 0.1, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_5  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RR.cm  &
   adams_id = 23  &
   location = -0.5, 0.25, 0.25  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RR.MARKER_27  &
   adams_id = 27  &
   location = -0.5, 0.1, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_27  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RR.MARKER_34  &
   adams_id = 34  &
   location = -0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_34  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RR.MARKER_42  &
   adams_id = 42  &
   location = -0.5, 0.25, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.strut_RR  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.strut_RR.CYLINDER_5  &
   adams_id = 5  &
   center_marker = .UGCV.strut_RR.MARKER_5  &
   angle_extent = 360.0  &
   length = 0.3  &
   radius = 2.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.strut_RR  &
   color = BLUE_GRAY  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- strut_RF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.strut_RF  &
   adams_id = 7  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.strut_RF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.strut_RF.MARKER_6  &
   adams_id = 6  &
   location = 0.5, 0.1, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_6  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RF.cm  &
   adams_id = 24  &
   location = 0.5, 0.25, 0.25  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RF.MARKER_11  &
   adams_id = 11  &
   location = 0.5, 0.1, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_11  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_RF.MARKER_36  &
   adams_id = 36  &
   location = 0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.strut_RF.MARKER_44  &
   adams_id = 44  &
   location = 0.5, 0.25, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.strut_RF  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.strut_RF.CYLINDER_6  &
   adams_id = 6  &
   center_marker = .UGCV.strut_RF.MARKER_6  &
   angle_extent = 360.0  &
   length = 0.3  &
   radius = 2.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.strut_RF  &
   color = BLUE_GRAY  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- strut_LR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.strut_LR  &
   adams_id = 8  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.strut_LR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.strut_LR.MARKER_7  &
   adams_id = 7  &
   location = -0.5, 0.1, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_7  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LR.cm  &
   adams_id = 25  &
   location = -0.5, 0.25, -0.25  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LR.MARKER_13  &
   adams_id = 13  &
   location = -0.5, 0.1, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_13  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LR.MARKER_40  &
   adams_id = 40  &
   location = -0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.strut_LR.MARKER_48  &
   adams_id = 48  &
   location = -0.5, 0.25, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.strut_LR  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.strut_LR.CYLINDER_7  &
   adams_id = 7  &
   center_marker = .UGCV.strut_LR.MARKER_7  &
   angle_extent = 360.0  &
   length = 0.3  &
   radius = 2.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.strut_LR  &
   color = BLUE_GRAY  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- strut_LF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.strut_LF  &
   adams_id = 9  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.strut_LF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.strut_LF.MARKER_8  &
   adams_id = 8  &
   location = 0.5, 0.1, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_8  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LF.cm  &
   adams_id = 26  &
   location = 0.5, 0.25, -0.25  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LF.MARKER_15  &
   adams_id = 15  &
   location = 0.5, 0.1, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_15  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.strut_LF.MARKER_38  &
   adams_id = 38  &
   location = 0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.strut_LF.MARKER_46  &
   adams_id = 46  &
   location = 0.5, 0.25, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.strut_LF  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.strut_LF.CYLINDER_8  &
   adams_id = 8  &
   center_marker = .UGCV.strut_LF.MARKER_8  &
   angle_extent = 360.0  &
   length = 0.3  &
   radius = 2.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.strut_LF  &
   color = BLUE_GRAY  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- mount_RR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.mount_RR  &
   adams_id = 10  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.mount_RR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.mount_RR.MARKER_29  &
   adams_id = 29  &
   location = -0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_29  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_RR.cm  &
   adams_id = 58  &
   location = -0.5, 0.4, 0.25  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_RR.MARKER_33  &
   adams_id = 33  &
   location = -0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_33  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_RR.MARKER_41  &
   adams_id = 41  &
   location = -0.5, 0.4, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.mount_RR.MARKER_51  &
   adams_id = 51  &
   location = -0.5, 0.5, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.mount_RR  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.mount_RR.CYLINDER_13  &
   adams_id = 13  &
   center_marker = .UGCV.mount_RR.MARKER_29  &
   angle_extent = 360.0  &
   length = 0.2  &
   radius = 3.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.mount_RR  &
   color = MIDNIGHT_BLUE  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- mount_RF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.mount_RF  &
   adams_id = 11  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.mount_RF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.mount_RF.MARKER_30  &
   adams_id = 30  &
   location = 0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_30  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_RF.cm  &
   adams_id = 59  &
   location = 0.5, 0.4, 0.25  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_RF.MARKER_35  &
   adams_id = 35  &
   location = 0.5, 0.3, 0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.mount_RF.MARKER_43  &
   adams_id = 43  &
   location = 0.5, 0.4, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.mount_RF.MARKER_53  &
   adams_id = 53  &
   location = 0.5, 0.5, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.mount_RF  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.mount_RF.CYLINDER_14  &
   adams_id = 14  &
   center_marker = .UGCV.mount_RF.MARKER_30  &
   angle_extent = 360.0  &
   length = 0.2  &
   radius = 3.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.mount_RF  &
   color = MIDNIGHT_BLUE  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- mount_LR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.mount_LR  &
   adams_id = 12  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.mount_LR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.mount_LR.MARKER_31  &
   adams_id = 31  &
   location = -0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_31  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_LR.cm  &
   adams_id = 60  &
   location = -0.5, 0.4, -0.25  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_LR.MARKER_39  &
   adams_id = 39  &
   location = -0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.mount_LR.MARKER_47  &
   adams_id = 47  &
   location = -0.5, 0.4, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.mount_LR.MARKER_55  &
   adams_id = 55  &
   location = -0.5, 0.5, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.mount_LR  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.mount_LR.CYLINDER_15  &
   adams_id = 15  &
   center_marker = .UGCV.mount_LR.MARKER_31  &
   angle_extent = 360.0  &
   length = 0.2  &
   radius = 3.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.mount_LR  &
   color = MIDNIGHT_BLUE  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- mount_LF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.mount_LF  &
   adams_id = 13  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.mount_LF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.mount_LF.MARKER_32  &
   adams_id = 32  &
   location = 0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker attributes  &
   marker_name = MARKER_32  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_LF.cm  &
   adams_id = 61  &
   location = 0.5, 0.4, -0.25  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker attributes  &
   marker_name = cm  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.mount_LF.MARKER_37  &
   adams_id = 37  &
   location = 0.5, 0.3, -0.25  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .UGCV.mount_LF.MARKER_45  &
   adams_id = 45  &
   location = 0.5, 0.4, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.mount_LF.MARKER_57  &
   adams_id = 57  &
   location = 0.5, 0.5, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.mount_LF  &
   material_type = .UGCV.aluminum
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.mount_LF.CYLINDER_16  &
   adams_id = 16  &
   center_marker = .UGCV.mount_LF.MARKER_32  &
   angle_extent = 360.0  &
   length = 0.2  &
   radius = 3.0E-002  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.mount_LF  &
   color = MIDNIGHT_BLUE  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
!---------------------------------- payload -----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.payload  &
   adams_id = 14  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.payload
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.payload.MARKER_49  &
   adams_id = 49  &
   location = -0.6, 0.3, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.payload.cm  &
   adams_id = 62  &
   location = -3.137254902E-002, 0.4549019608, 0.0  &
   orientation = 91.5192798208d, 90.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.payload.MARKER_50  &
   adams_id = 50  &
   location = -0.5, 0.5, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.payload.MARKER_52  &
   adams_id = 52  &
   location = 0.5, 0.5, 0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.payload.MARKER_54  &
   adams_id = 54  &
   location = -0.5, 0.5, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.payload.MARKER_56  &
   adams_id = 56  &
   location = 0.5, 0.5, -0.25  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.payload  &
   density = 500.0
!
! ****** Graphics for current part ******
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.payload.MARKER_49
!
geometry create shape extrusion  &
   extrusion_name = .UGCV.payload.EXTRUSION_33  &
   reference_marker = .UGCV.payload.MARKER_49  &
   analytical = no  &
   points_for_profile = 0.0, 0.0, -0.25  &
      , 1.0, 0.0, -0.25  &
      , 1.2, 0.2, -0.25  &
      , 1.2, 0.3, -0.25  &
      , 0.0, 0.3, -0.25  &
      , 0.0, 0.0, -0.25  &
   length_along_z_axis = 0.5
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.payload
!
part attributes  &
   part_name = .UGCV.payload  &
   color = MAIZE  &
   name_visibility = off
!
!---------------------------------- wheel_RF ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.wheel_RF  &
   adams_id = 15  &
   location = 2.0, 0.0, 0.15  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.wheel_RF
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.wheel_RF.MARKER_12  &
   adams_id = 12  &
   location = -1.5, 0.1, 0.1  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_12  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.wheel_RF.MARKER_64  &
   adams_id = 64  &
   location = -1.5, 0.1, 5.0E-002  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.wheel_RF.cm  &
   adams_id = 67  &
   location = -1.5, 0.1, 0.1  &
   orientation = 270.0d, 90.0d, 90.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.wheel_RF  &
   density = 400.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.wheel_RF.CYLINDER_46  &
   adams_id = 46  &
   center_marker = .UGCV.wheel_RF.MARKER_64  &
   angle_extent = 360.0  &
   length = 0.1  &
   radius = 0.12  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.wheel_RF  &
   color = DARK_GRAY  &
   name_visibility = off
!
!---------------------------------- wheel_LR ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
part create rigid_body name_and_position  &
   part_name = .UGCV.wheel_LR  &
   adams_id = 18  &
   location = 0.8, 0.0, 0.65  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.wheel_LR
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .UGCV.wheel_LR.MARKER_14  &
   adams_id = 14  &
   location = -1.3, 0.1, -0.9  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = MARKER_14  &
   size_of_icons = 3.0E-002
!
marker create  &
   marker_name = .UGCV.wheel_LR.MARKER_70  &
   adams_id = 70  &
   location = -1.3, 0.1, -0.95  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .UGCV.wheel_LR.cm  &
   adams_id = 73  &
   location = -1.3, 0.1, -0.9  &
   orientation = 270.0d, 90.0d, 90.0d
!
part create rigid_body mass_properties  &
   part_name = .UGCV.wheel_LR  &
   density = 400.0
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .UGCV.wheel_LR.CYLINDER_49  &
   adams_id = 49  &
   center_marker = .UGCV.wheel_LR.MARKER_70  &
   angle_extent = 360.0  &
   length = 0.1  &
   radius = 0.12  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .UGCV.wheel_LR  &
   color = DARK_GRAY  &
   name_visibility = off
!
!---------------------------------- Contacts ----------------------------------!
!
!
contact create  &
   contact_name = .UGCV.CONTACT_1  &
   adams_id = 1  &
   i_geometry_name = .UGCV.wheel_RF.CYLINDER_46  &
   j_geometry_name = .UGCV.ground.EXTRUSION_34  &
   stiffness = 1.0E+006  &
   damping = 1.0E+005  &
   exponent = 1.6  &
   dmax = 1.0E-004  &
   coulomb_friction = on  &
   mu_static = 0.5  &
   mu_dynamic = 0.4  &
   stiction_transition_velocity = 1.0E-002  &
   friction_transition_velocity = 0.1
!
contact create  &
   contact_name = .UGCV.CONTACT_2  &
   adams_id = 2  &
   i_geometry_name = .UGCV.wheel_RR.CYLINDER_48  &
   j_geometry_name = .UGCV.ground.EXTRUSION_34  &
   stiffness = 1.0E+006  &
   damping = 1.0E+005  &
   exponent = 1.6  &
   dmax = 1.0E-004  &
   coulomb_friction = on  &
   mu_static = 0.5  &
   mu_dynamic = 0.4  &
   stiction_transition_velocity = 1.0E-002  &
   friction_transition_velocity = 0.1
!
contact create  &
   contact_name = .UGCV.CONTACT_3  &
   adams_id = 3  &
   i_geometry_name = .UGCV.wheel_LR.CYLINDER_49  &
   j_geometry_name = .UGCV.ground.EXTRUSION_34  &
   stiffness = 1.0E+006  &
   damping = 1.0E+005  &
   exponent = 1.6  &
   dmax = 1.0E-004  &
   coulomb_friction = on  &
   mu_static = 0.5  &
   mu_dynamic = 0.4  &
   stiction_transition_velocity = 1.0E-002  &
   friction_transition_velocity = 0.1
!
contact create  &
   contact_name = .UGCV.CONTACT_4  &
   adams_id = 4  &
   i_geometry_name = .UGCV.wheel_LF.CYLINDER_47  &
   j_geometry_name = .UGCV.ground.EXTRUSION_34  &
   stiffness = 1.0E+006  &
   damping = 1.0E+005  &
   exponent = 1.6  &
   dmax = 1.0E-004  &
   coulomb_friction = on  &
   mu_static = 0.5  &
   mu_dynamic = 0.4  &
   stiction_transition_velocity = 1.0E-002  &
   friction_transition_velocity = 0.1
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint revolute  &
   joint_name = .UGCV.axle_RR  &
   adams_id = 5  &
   i_marker_name = .UGCV.strut_RR.MARKER_27  &
   j_marker_name = .UGCV.wheel_RR.MARKER_28
!
constraint attributes  &
   constraint_name = .UGCV.axle_RR  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create joint revolute  &
   joint_name = .UGCV.axle_RF  &
   adams_id = 2  &
   i_marker_name = .UGCV.strut_RF.MARKER_11  &
   j_marker_name = .UGCV.wheel_RF.MARKER_12
!
constraint attributes  &
   constraint_name = .UGCV.axle_RF  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create joint revolute  &
   joint_name = .UGCV.axle_LR  &
   adams_id = 3  &
   i_marker_name = .UGCV.strut_LR.MARKER_13  &
   j_marker_name = .UGCV.wheel_LR.MARKER_14
!
constraint attributes  &
   constraint_name = .UGCV.axle_LR  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create joint revolute  &
   joint_name = .UGCV.axle_LF  &
   adams_id = 4  &
   i_marker_name = .UGCV.strut_LF.MARKER_15  &
   j_marker_name = .UGCV.wheel_LF.MARKER_16
!
constraint attributes  &
   constraint_name = .UGCV.axle_LF  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create joint translational  &
   joint_name = .UGCV.slider_RR  &
   adams_id = 6  &
   i_marker_name = .UGCV.mount_RR.MARKER_33  &
   j_marker_name = .UGCV.strut_RR.MARKER_34
!
constraint attributes  &
   constraint_name = .UGCV.slider_RR  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create joint cylindrical  &
   joint_name = .UGCV.swivel_RF  &
   adams_id = 7  &
   i_marker_name = .UGCV.mount_RF.MARKER_35  &
   j_marker_name = .UGCV.strut_RF.MARKER_36
!
constraint attributes  &
   constraint_name = .UGCV.swivel_RF  &
   name_visibility = off
!
constraint create joint cylindrical  &
   joint_name = .UGCV.swivel_LF  &
   adams_id = 8  &
   i_marker_name = .UGCV.mount_LF.MARKER_37  &
   j_marker_name = .UGCV.strut_LF.MARKER_38
!
constraint attributes  &
   constraint_name = .UGCV.swivel_LF  &
   name_visibility = off
!
constraint create joint translational  &
   joint_name = .UGCV.slider_LR  &
   adams_id = 9  &
   i_marker_name = .UGCV.mount_LR.MARKER_39  &
   j_marker_name = .UGCV.strut_LR.MARKER_40
!
constraint attributes  &
   constraint_name = .UGCV.slider_LR  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .UGCV.fix_RR  &
   adams_id = 10  &
   i_marker_name = .UGCV.payload.MARKER_50  &
   j_marker_name = .UGCV.mount_RR.MARKER_51
!
constraint attributes  &
   constraint_name = .UGCV.fix_RR  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .UGCV.fix_RF  &
   adams_id = 11  &
   i_marker_name = .UGCV.payload.MARKER_52  &
   j_marker_name = .UGCV.mount_RF.MARKER_53
!
constraint attributes  &
   constraint_name = .UGCV.fix_RF  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .UGCV.fix_LR  &
   adams_id = 12  &
   i_marker_name = .UGCV.payload.MARKER_54  &
   j_marker_name = .UGCV.mount_LR.MARKER_55
!
constraint attributes  &
   constraint_name = .UGCV.fix_LR  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .UGCV.fix_LF  &
   adams_id = 13  &
   i_marker_name = .UGCV.payload.MARKER_56  &
   j_marker_name = .UGCV.mount_LF.MARKER_57
!
constraint attributes  &
   constraint_name = .UGCV.fix_LF  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
!---------------------------------- Motions -----------------------------------!
!
!
constraint create motion_generator  &
   motion_name = .UGCV.MOTION_RR  &
   adams_id = 1  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.axle_RR  &
   time_derivative = velocity  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.MOTION_RR  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create motion_generator  &
   motion_name = .UGCV.MOTION_RF  &
   adams_id = 2  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.axle_RF  &
   time_derivative = velocity  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.MOTION_RF  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create motion_generator  &
   motion_name = .UGCV.MOTION_LF  &
   adams_id = 3  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.axle_LF  &
   time_derivative = velocity  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.MOTION_LF  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create motion_generator  &
   motion_name = .UGCV.MOTION_LR  &
   adams_id = 4  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.axle_LR  &
   time_derivative = velocity  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.MOTION_LR  &
   name_visibility = off  &
   size_of_icons = 3.0E-002
!
constraint create motion_generator  &
   motion_name = .UGCV.steer_LF  &
   adams_id = 5  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.swivel_LF  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.steer_LF  &
   name_visibility = off
!
constraint create motion_generator  &
   motion_name = .UGCV.steer_RF  &
   adams_id = 6  &
   type_of_freedom = rotational  &
   joint_name = .UGCV.swivel_RF  &
   function = ""
!
constraint attributes  &
   constraint_name = .UGCV.steer_RF  &
   name_visibility = off
!
!---------------------------- Adams/View Variables ----------------------------!
!
!
variable create  &
   variable_name = .UGCV.DV_shock_k  &
   units = "stiffness"  &
   range = 2000.0, 4000.0  &
   use_allowed_values = no  &
   real_value = 4000.0
!
variable create  &
   variable_name = .UGCV.DV_shock_preload  &
   units = "force"  &
   range = 100.0, 250.0  &
   use_allowed_values = no  &
   real_value = 180.0
!
variable create  &
   variable_name = .UGCV.DV_shock_C  &
   units = "damping"  &
   range = 0.0, 500.0  &
   use_allowed_values = no  &
   real_value = 100.0
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .UGCV.Last_Sim  &
   commands =   &
              "simulation single_run scripted sim_script_name=.rover.SIM_SCRIPT_1 reset_before_and_after=yes model_name=.rover"
!
simulation script create  &
   sim_script_name = .UGCV.SIM_SCRIPT_1  &
   type = auto_select  &
   initial_static = no  &
   number_of_steps = 1000  &
   end_time = 10.0
!
!-------------------------- Adams/View UDE Instances --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
undo begin_block suppress = yes
!
ude create instance  &
   instance_name = .UGCV.shock_RR  &
   definition_name = .MDI.Forces.spring  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .UGCV.shock_RR  &
   color = RED
!
ude create instance  &
   instance_name = .UGCV.shock_RF  &
   definition_name = .MDI.Forces.spring  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .UGCV.shock_RF  &
   color = RED
!
ude create instance  &
   instance_name = .UGCV.shock_LF  &
   definition_name = .MDI.Forces.spring  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .UGCV.shock_LF  &
   color = RED
!
ude create instance  &
   instance_name = .UGCV.shock_LR  &
   definition_name = .MDI.Forces.spring  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .UGCV.shock_LR  &
   color = RED
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .UGCV.shock_RR.i_marker  &
   object_value = (.UGCV.mount_RR.MARKER_41)
!
variable modify  &
   variable_name = .UGCV.shock_RR.j_marker  &
   object_value = (.UGCV.strut_RR.MARKER_42)
!
variable modify  &
   variable_name = .UGCV.shock_RR.stiffness_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_RR.stiffness_coefficient  &
   real_value = (.UGCV.DV_shock_k)
!
variable modify  &
   variable_name = .UGCV.shock_RR.stiffness_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_RR.damping_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_RR.damping_coefficient  &
   real_value = (.UGCV.DV_shock_C)
!
variable modify  &
   variable_name = .UGCV.shock_RR.damping_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_RR.free_length_mode  &
   string_value = "Design_Length"
!
variable modify  &
   variable_name = .UGCV.shock_RR.free_length  &
   real_value = 1.0
!
variable modify  &
   variable_name = .UGCV.shock_RR.preload  &
   real_value = (.UGCV.DV_shock_preload + 20)
!
variable modify  &
   variable_name = .UGCV.shock_RR.i_dynamic_visibility  &
   string_value = "On"
!
variable modify  &
   variable_name = .UGCV.shock_RR.j_dynamic_visibility  &
   string_value = "Off"
!
variable modify  &
   variable_name = .UGCV.shock_RR.spring_visibility  &
   string_value = "depends"
!
variable modify  &
   variable_name = .UGCV.shock_RR.damper_visibility  &
   string_value = "never"
!
ude modify instance  &
   instance_name = .UGCV.shock_RR
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .UGCV.shock_RF.i_marker  &
   object_value = (.UGCV.mount_RF.MARKER_43)
!
variable modify  &
   variable_name = .UGCV.shock_RF.j_marker  &
   object_value = (.UGCV.strut_RF.MARKER_44)
!
variable modify  &
   variable_name = .UGCV.shock_RF.stiffness_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_RF.stiffness_coefficient  &
   real_value = (.UGCV.DV_shock_k)
!
variable modify  &
   variable_name = .UGCV.shock_RF.stiffness_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_RF.damping_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_RF.damping_coefficient  &
   real_value = (.UGCV.DV_shock_C)
!
variable modify  &
   variable_name = .UGCV.shock_RF.damping_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_RF.free_length_mode  &
   string_value = "Design_Length"
!
variable modify  &
   variable_name = .UGCV.shock_RF.free_length  &
   real_value = 1.0
!
variable modify  &
   variable_name = .UGCV.shock_RF.preload  &
   real_value = (.UGCV.DV_shock_preload)
!
variable modify  &
   variable_name = .UGCV.shock_RF.i_dynamic_visibility  &
   string_value = "On"
!
variable modify  &
   variable_name = .UGCV.shock_RF.j_dynamic_visibility  &
   string_value = "Off"
!
variable modify  &
   variable_name = .UGCV.shock_RF.spring_visibility  &
   string_value = "depends"
!
variable modify  &
   variable_name = .UGCV.shock_RF.damper_visibility  &
   string_value = "never"
!
ude modify instance  &
   instance_name = .UGCV.shock_RF
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .UGCV.shock_LF.i_marker  &
   object_value = (.UGCV.mount_LF.MARKER_45)
!
variable modify  &
   variable_name = .UGCV.shock_LF.j_marker  &
   object_value = (.UGCV.strut_LF.MARKER_46)
!
variable modify  &
   variable_name = .UGCV.shock_LF.stiffness_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_LF.stiffness_coefficient  &
   real_value = (.UGCV.DV_shock_k)
!
variable modify  &
   variable_name = .UGCV.shock_LF.stiffness_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_LF.damping_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_LF.damping_coefficient  &
   real_value = (.UGCV.DV_shock_C)
!
variable modify  &
   variable_name = .UGCV.shock_LF.damping_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_LF.free_length_mode  &
   string_value = "Design_Length"
!
variable modify  &
   variable_name = .UGCV.shock_LF.free_length  &
   real_value = 1.0
!
variable modify  &
   variable_name = .UGCV.shock_LF.preload  &
   real_value = (.UGCV.DV_shock_preload)
!
variable modify  &
   variable_name = .UGCV.shock_LF.i_dynamic_visibility  &
   string_value = "On"
!
variable modify  &
   variable_name = .UGCV.shock_LF.j_dynamic_visibility  &
   string_value = "Off"
!
variable modify  &
   variable_name = .UGCV.shock_LF.spring_visibility  &
   string_value = "depends"
!
variable modify  &
   variable_name = .UGCV.shock_LF.damper_visibility  &
   string_value = "never"
!
ude modify instance  &
   instance_name = .UGCV.shock_LF
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .UGCV.shock_LR.i_marker  &
   object_value = (.UGCV.mount_LR.MARKER_47)
!
variable modify  &
   variable_name = .UGCV.shock_LR.j_marker  &
   object_value = (.UGCV.strut_LR.MARKER_48)
!
variable modify  &
   variable_name = .UGCV.shock_LR.stiffness_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_LR.stiffness_coefficient  &
   real_value = (.UGCV.DV_shock_k)
!
variable modify  &
   variable_name = .UGCV.shock_LR.stiffness_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_LR.damping_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .UGCV.shock_LR.damping_coefficient  &
   real_value = (.UGCV.DV_shock_C)
!
variable modify  &
   variable_name = .UGCV.shock_LR.damping_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .UGCV.shock_LR.free_length_mode  &
   string_value = "Design_Length"
!
variable modify  &
   variable_name = .UGCV.shock_LR.free_length  &
   real_value = 1.0
!
variable modify  &
   variable_name = .UGCV.shock_LR.preload  &
   real_value = (.UGCV.DV_shock_preload + 20)
!
variable modify  &
   variable_name = .UGCV.shock_LR.i_dynamic_visibility  &
   string_value = "On"
!
variable modify  &
   variable_name = .UGCV.shock_LR.j_dynamic_visibility  &
   string_value = "Off"
!
variable modify  &
   variable_name = .UGCV.shock_LR.spring_visibility  &
   string_value = "depends"
!
variable modify  &
   variable_name = .UGCV.shock_LR.damper_visibility  &
   string_value = "never"
!
ude modify instance  &
   instance_name = .UGCV.shock_LR
!
undo end_block
!
!------------------------------ Dynamic Graphics ------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .UGCV.ground
!
geometry create shape gcontact  &
   contact_force_name = .UGCV.GCONTACT_68  &
   adams_id = 68  &
   contact_element_name = .UGCV.CONTACT_1  &
   force_display = components
!
geometry create shape gcontact  &
   contact_force_name = .UGCV.GCONTACT_71  &
   adams_id = 71  &
   contact_element_name = .UGCV.CONTACT_2  &
   force_display = components
!
geometry create shape gcontact  &
   contact_force_name = .UGCV.GCONTACT_74  &
   adams_id = 74  &
   contact_element_name = .UGCV.CONTACT_3  &
   force_display = components
!
geometry create shape gcontact  &
   contact_force_name = .UGCV.GCONTACT_77  &
   adams_id = 77  &
   contact_element_name = .UGCV.CONTACT_4  &
   force_display = components
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9.80665  &
   z_component_gravity = 0.0
!
force attributes  &
   force_name = gravity  &
   size_of_icons = 3.0E-002
!
!----------------------------- Analysis settings ------------------------------!
!
!
executive_control set numerical_integration_parameters  &
   model_name = UGCV  &
   formulation = si2  &
   error_tolerance = 1.0E-002  &
   scale = 1.0, 1.0, 1.0E-003  &
   kmax_integrator_order = 6
!
executive_control set equilibrium_parameters  &
   model_name = UGCV  &
   alimit = 1.0d  &
   error = 1.0E-003  &
   imbalance = 1.0E-003  &
   maxit = 50  &
   stability = 1.0E-004  &
   tlimit = 2.0E-004
!
!---------------------------- Adams/View Variables ----------------------------!
!
!
variable create  &
   variable_name = .UGCV.wheel_rate  &
   units = "angular_velocity"  &
   range = 10.0, 1000.0  &
   use_allowed_values = no  &
   real_value = 500.0
!
!---------------------------- Function definitions ----------------------------!
!
!
constraint modify motion_generator  &
   motion_name = .UGCV.MOTION_RR  &
   function = "step(time,0,0,1,.UGCV.wheel_rate)"
!
constraint modify motion_generator  &
   motion_name = .UGCV.MOTION_RF  &
   function = "step(time,0,0,1,.UGCV.wheel_rate)"
!
constraint modify motion_generator  &
   motion_name = .UGCV.MOTION_LF  &
   function = "step(time,0,0,1,.UGCV.wheel_rate)"
!
constraint modify motion_generator  &
   motion_name = .UGCV.MOTION_LR  &
   function = "step(time,0,0,1,.UGCV.wheel_rate)"
!
constraint modify motion_generator  &
   motion_name = .UGCV.steer_LF  &
   function = "varval(.UGCV.cmd_heading)"
!
constraint modify motion_generator  &
   motion_name = .UGCV.steer_RF  &
   function = "varval(.UGCV.cmd_heading)"
!
data_element modify variable  &
   variable_name = .UGCV.cmd_heading  &
   function = "step(time,1,0,3,20d) + step(time,4,0,6,-50d)"
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .UGCV.shock_RR
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .UGCV.shock_RF
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .UGCV.shock_LF
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .UGCV.shock_LR
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
material modify  &
   material_name = .UGCV.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
material modify  &
   material_name = .UGCV.aluminum  &
   youngs_modulus = (7.1705E+010(Newton/meter**2))  &
   density = (2740.0(kg/meter**3))
!
part modify rigid_body mass_properties  &
   part_name = .UGCV.wheel_LF  &
   density = (400.0(kg/meter**3))
!
part modify rigid_body mass_properties  &
   part_name = .UGCV.wheel_RR  &
   density = (400.0(kg/meter**3))
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.strut_RR.CYLINDER_5  &
   length = (0.3meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.strut_RF.CYLINDER_6  &
   length = (0.3meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.strut_LR.CYLINDER_7  &
   length = (0.3meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.strut_LF.CYLINDER_8  &
   length = (0.3meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.mount_RR.CYLINDER_13  &
   length = (0.2meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.mount_RF.CYLINDER_14  &
   length = (0.2meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.mount_LR.CYLINDER_15  &
   length = (0.2meter)
!
geometry modify shape cylinder  &
   cylinder_name = .UGCV.mount_LF.CYLINDER_16  &
   length = (0.2meter)
!
part modify rigid_body mass_properties  &
   part_name = .UGCV.payload  &
   density = (500.0(kg/meter**3))
!
part modify rigid_body mass_properties  &
   part_name = .UGCV.wheel_RF  &
   density = (400.0(kg/meter**3))
!
part modify rigid_body mass_properties  &
   part_name = .UGCV.wheel_LR  &
   density = (400.0(kg/meter**3))
!
model display  &
   model_name = UGCV


view manage orient view=iso up_axis=(.MDI.up_axis) forward_axis=(.MDI.forward_axis)
view rotate view=.gui.main.front screen=-19.9590842916, 20.0924879247, -3.1377122631

executive set numerical model = .UGCV formulation = I3

simulation single transient type=auto_select duration=12.5 step_size=0.01

int view undisp view=all
int view mod  view=.gui.main.front loc=0.0,0.0 height=0.5 width=1
int view mod  view=.gui.main.right loc=0.0,0.5 height=0.5 width=0.5
int view mod  view=.gui.main.top loc=0.5,0.5 height=0.5 width=0.5
int view disp view=.gui.main.front,.gui.main.right,.gui.main.top
if cond=1
  if cond=0
     model display view=.gui.main.front
  end
  if cond=0
     model display view=.gui.main.right
  end
  if cond=0
     model display view=.gui.main.top
  end
end
view zoom auto=on view=all

graphic_results animate  &
   analysis_name = .UGCV.Last_Run  &
   view_name = main.top, main.front, main.right  &
   number_of_cycles = 1  &
   time_range = 0.0 , 8.45775  &
     &
   superimposed = off  &
   contour_plots = on  &
     &
     &
     &
     &
   icon_visibility = off  &
   increment_frame_by=(1*( "1" != "" ? "1" : 1 ))
interface slider modify slider=.gui.animate_full_panel.frame &
    value=1251

graphic_results animate  &
   analysis_name = .UGCV.Last_Run  &
   view_name = main.top  &
   number_of_cycles = 1  &
   time_range = 0.0 , 8.45775  &
     &
   superimposed = on  &
   contour_plots = on  &
     &
     &
     &
     &
   icon_visibility = off  &
   increment_frame_by=(1*( "10" != "" ? "10" : 1 ))
interface slider modify slider=.gui.animate_full_panel.frame &
    value=1251

interface dialog undisplay dialog=.gui.animate_full_panel
interface plot window open
interface window undisplay window=.gui.main

  interface page modify layout=page2x2 set_contents = yes
  interface plot window update_toolbar

xy_plot template modify plot=.plot_1 auto_title=yes auto_subtitle=no auto_date=yes auto_analysis_name=yes table=no
xy_plot curve create curve=.plot_1.curve_1 create_page=no calculate_axis_limits=no dmeasure=.UGCV.shock_LF.force run=.UGCV.Last_Run auto_axis=UNITS
xy_plot template calculate_axis_limits plot_name=.plot_1
interface plot window update_toolbar

xy_plot template modify plot=.plot_2 auto_title=yes auto_subtitle=no auto_date=yes auto_analysis_name=yes table=no
xy_plot curve create curve=.plot_2.curve_1 create_page=no calculate_axis_limits=no dmeasure=.UGCV.shock_LR.force run=.UGCV.Last_Run auto_axis=UNITS
xy_plot template calculate_axis_limits plot_name=.plot_2
interface plot window update_toolbar

xy_plot template modify plot=.plot_4 auto_title=yes auto_subtitle=no auto_date=yes auto_analysis_name=yes table=no
xy_plot curve create curve=.plot_4.curve_1 create_page=no calculate_axis_limits=no dmeasure=.UGCV.shock_RR.force run=.UGCV.Last_Run auto_axis=UNITS
xy_plot template calculate_axis_limits plot_name=.plot_4
interface plot window update_toolbar

xy_plot template modify plot=.plot_3 auto_title=yes auto_subtitle=no auto_date=yes auto_analysis_name=yes table=no
xy_plot curve create curve=.plot_3.curve_1 create_page=no calculate_axis_limits=no dmeasure=.UGCV.shock_RF.force run=.UGCV.Last_Run auto_axis=UNITS
xy_plot template calculate_axis_limits plot_name=.plot_3
interface plot window update_toolbar

animation pause page_name=page_1
animation record stop
interface win disp win=.gui.main
interface plot window close
